@@ -418,11 +418,11 @@ int TVIL_AnalyticITYPE (TVIL_ITYPE *foo, TVIL_REAL qq)
 
 /* ****************************************************************** */
 
-int TVIL_SetAllIs (TVIL_DATA *foo)
+int TVIL_SetAllIs (void)
 {
   int i;
-  for (i=0; i<NUM_I_FUNCS; i++)
-    TVIL_AnalyticITYPE (&(foo->II[i]), foo->qq);
+  for (i=0; i<_nIfuns; i++)
+    TVIL_AnalyticITYPE (_ifun[i], _qq);
 
   /* Make this meaningful eventually? */
   return 0;
@@ -437,16 +437,16 @@ TVIL_COMPLEX TVIL_TestI (TVIL_ITYPE *foo, TVIL_REAL qq)
 
 /* ****************************************************************** */
 
-int TVIL_TestAllIs (TVIL_DATA *foo)
+int TVIL_TestAllIs (void)
 {
   int i;
   TVIL_COMPLEX ANALresult, RKresult, diff;
 
   printf("\nTesting I functions at t=1:\n");
 
-  for (i=0; i<NUM_I_FUNCS; i++) {
-    ANALresult = TVIL_TestI (&(foo->II[i]), foo->qq);
-    RKresult = foo->II[i].value;
+  for (i=0; i<_nIfuns; i++) {
+    ANALresult = TVIL_TestI (_ifun[i], _qq);
+    RKresult = _ifun[i]->value;
     diff = RKresult - ANALresult;
     printf("Analytic value = "); TVIL_cprintf(ANALresult); printf("\n");
     printf("RK       value = "); TVIL_cprintf(RKresult); printf("\n");
@@ -460,9 +460,9 @@ int TVIL_TestAllIs (TVIL_DATA *foo)
 
 int TVIL_SetI_complex (TVIL_ITYPE *foo, TVIL_REAL qq, TVIL_COMPLEX t)
 {
-  foo->value = TVIL_I2_complex_args (a + t * (foo->arg[0] - a),
-				     a + t * (foo->arg[1] - a),
-				     a + t * (foo->arg[2] - a),
+  foo->value = TVIL_I2_complex_args (_a + t * (foo->arg[0] - _a),
+				     _a + t * (foo->arg[1] - _a),
+				     _a + t * (foo->arg[2] - _a),
 				     qq);
 
   /* Make this meaningful eventually? */
@@ -471,11 +471,11 @@ int TVIL_SetI_complex (TVIL_ITYPE *foo, TVIL_REAL qq, TVIL_COMPLEX t)
 
 /* ****************************************************************** */
 
-int TVIL_SetAllIs_complex (TVIL_DATA *foo, TVIL_COMPLEX t)
+int TVIL_SetAllIs_complex (TVIL_COMPLEX t)
 {
   int i;
-  for (i=0; i<NUM_I_FUNCS; i++)
-    TVIL_SetI_complex (&(foo->II[i]), foo->qq, t);
+  for (i=0; i<_nIfuns; i++)
+    TVIL_SetI_complex (_ifun[i], _qq, t);
 
   /* Make this meaningful eventually? */
   return 0;
@@ -485,24 +485,24 @@ int TVIL_SetAllIs_complex (TVIL_DATA *foo, TVIL_COMPLEX t)
 
 TVIL_COMPLEX TVIL_TestI_complex (TVIL_ITYPE *foo, TVIL_REAL qq, TVIL_COMPLEX t)
 {
-  return TVIL_I2_complex_args (a + t * (foo->arg[0] - a),
-                               a + t * (foo->arg[1] - a),
-                               a + t * (foo->arg[2] - a),
+  return TVIL_I2_complex_args (_a + t * (foo->arg[0] - _a),
+                               _a + t * (foo->arg[1] - _a),
+                               _a + t * (foo->arg[2] - _a),
                                qq);
 }
 
 /* ****************************************************************** */
 
-int TVIL_TestAllIs_complex (TVIL_DATA *foo, TVIL_COMPLEX t)
+int TVIL_TestAllIs_complex (TVIL_COMPLEX t)
 {
   int i;
   TVIL_COMPLEX ANALresult, RKresult, diff;
 
   printf("\nTesting I functions at t = ");TVIL_cprintf(t); printf("\n");
 
-  for (i=0; i<NUM_I_FUNCS; i++) {
-    ANALresult = TVIL_TestI_complex (&(foo->II[i]), foo->qq, t);
-    RKresult = foo->II[i].value;
+  for (i=0; i<_nIfuns; i++) {
+    ANALresult = TVIL_TestI_complex (_ifun[i], _qq, t);
+    RKresult = _ifun[i]->value;
     diff = RKresult - ANALresult;
     printf("Analytic value = "); TVIL_cprintf(ANALresult); printf("\n");
     printf("RK       value = "); TVIL_cprintf(RKresult); printf("\n");
@@ -519,9 +519,9 @@ int TVIL_InitialI (TVIL_ITYPE *foo,
 		   TVIL_REAL qq,
 		   TVIL_COMPLEX tinit)
 {
-  TVIL_REAL x = (foo->arg[0])/a;
-  TVIL_REAL y = (foo->arg[1])/a;
-  TVIL_REAL z = (foo->arg[2])/a;
+  TVIL_REAL x = (foo->arg[0])/_a;
+  TVIL_REAL y = (foo->arg[1])/_a;
+  TVIL_REAL z = (foo->arg[2])/_a;
   TVIL_REAL Iexp[10];
   TVIL_REAL x2, x3, x4, x5, x6, x7, x8, x9;
   TVIL_REAL y2, y3, y4, y5, y6, y7, y8, y9;
@@ -530,7 +530,7 @@ int TVIL_InitialI (TVIL_ITYPE *foo,
   TVIL_COMPLEX ttothei, result;
   int i, nTerms = 10;
 
-  lnbara = TVIL_LOG (a/qq);
+  lnbara = TVIL_LOG (_a/qq);
   lnbara2 = lnbara * lnbara;
 
   x2 = x*x;
@@ -965,7 +965,7 @@ int TVIL_InitialI (TVIL_ITYPE *foo,
     ttothei *= tinit;
     result += Iexp[i]*ttothei;
   }
-  foo->value = a * result;
+  foo->value = _a * result;
 
   ttothei = 1.0L;
   result = Iexp[1];
@@ -974,7 +974,7 @@ int TVIL_InitialI (TVIL_ITYPE *foo,
     ttothei *= tinit;
     result += i*Iexp[i]*ttothei;
   }
-  foo->deriv = a * result;
+  foo->deriv = _a * result;
 
   return 0;
 }
