@@ -4,12 +4,12 @@
 
 /* **************************************************************** */
 
-void TVIL_SetParamsE (TVIL_ETYPE *foo,
-		      int whichfun,
-		      TVIL_REAL x,
-		      TVIL_REAL y,
-		      TVIL_REAL z,
-		      TVIL_REAL u)
+TVIL_ETYPE *TVIL_SetParamsE (TVIL_ETYPE *foo,
+			     int whichfun,
+			     TVIL_REAL x,
+			     TVIL_REAL y,
+			     TVIL_REAL z,
+			     TVIL_REAL u)
 {
   foo->which = whichfun;
   foo->arg[0] = x;
@@ -17,5 +17,5 @@ void TVIL_SetParamsE (TVIL_ETYPE *foo,
   foo->arg[2] = z;
   foo->arg[3] = u;
 
-  return;
+  return foo;
 }
