@@ -159,15 +159,14 @@ TVIL_COMPLEX TVIL_TrilogCLZseries(TVIL_COMPLEX z)
 }
 
 /* ************************************************************** */
+/* Improved version thanks to Alexander Voigt, new in 3vil v2.01  */
 
 TVIL_COMPLEX TVIL_Trilogseries (TVIL_COMPLEX z)
 {
   TVIL_REAL absz = TVIL_CABS (z);
   TVIL_REAL logepsilon = TVIL_LOG (TVIL_TOL);
   TVIL_REAL mlogabsz;
-  TVIL_COMPLEX sum = z;
-  TVIL_COMPLEX ztothek;
-  TVIL_COMPLEX term;
+  TVIL_COMPLEX sum = 0;
   TVIL_COMPLEX kcubed;
   int k, kmax;
 
@@ -180,14 +179,12 @@ TVIL_COMPLEX TVIL_Trilogseries (TVIL_COMPLEX z)
 */
 
   kmax = 5 + (int) (( 6.0 -logepsilon -3.0 * log(-logepsilon)
-		      + 3.0 * log (mlogabsz)) / mlogabsz);
+                      + 3.0 * log (mlogabsz)) / mlogabsz);
 
-  for (k = kmax; k > 1; k--)
+  for (k = kmax; k >= 1; k--)
     {
-      ztothek = TVIL_CPOW (z, k);
       kcubed = k*k*k;
-      term = ztothek/kcubed;
-      sum += term;
+      sum = z*(sum + 1/kcubed);
     }
 
   return sum;
